==> mailjet-client-4.1.1-sources.jar: com/mailjet/client/resource/Graphstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Graphstatistics {

    public static Resource resource = new Resource("graphstatistics", "");

	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String REFTIMESTAMP = "RefTimestamp";
	public static String SENDTIMESTART = "SendtimeStart";
	public static String SPAMCOMPLAINTCOUNT = "SpamcomplaintCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACT = "Contact";
	public static String CONTACTSLIST = "ContactsList";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String SCALE = "Scale";
	public static String TIMESHIFT = "TimeShift";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-4.2.1-sources.jar: com/mailjet/client/resource/Graphstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Graphstatistics {

    public static Resource resource = new Resource("graphstatistics", "");

	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String REFTIMESTAMP = "RefTimestamp";
	public static String SENDTIMESTART = "SendtimeStart";
	public static String SPAMCOMPLAINTCOUNT = "SpamcomplaintCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACT = "Contact";
	public static String CONTACTSLIST = "ContactsList";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String SCALE = "Scale";
	public static String TIMESHIFT = "TimeShift";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";
	public static final String SOFTBOUNCEDCOUNT = "SoftbouncedCount";
	public static final String HARDBOUNCEDCOUNT = "HardbouncedCount";
	public static final String DEFERREDCOUNT = "DeferredCount";

}
